Learn R Programming

gaiah (version 0.0.5)

example_isotope_posteriors: Output of isotope_posterior_probs for two migrant birds.

Description

Because it takes too long to generate this output for future examples, we just store it as a data object to use in examples. See the example in isotope_posterior_probs to see what this is.

Usage

example_isotope_posteriors

Arguments

Format

An object of class list of length 2.