Learn R Programming

gaiah (version 0.0.5)

get_wrld_simpl: return the wrld_simpl data set from maptools

Description

I define this as a function so that we don't have to attach maptools, but we can just have it in the imports. Couldn't figure out how to do it otherwise.

Usage

get_wrld_simpl()

Arguments

Examples

Run this code
ws <- get_wrld_simpl()
head(ws)
if (FALSE) plot(ws)

Run the code above in your browser using DataLab