# We compute the great circle distance between the lat/long of my office in
# California, to every cell in the raster denoting the breeding habitat
# of Wilson's warbler:
gcr <- great_circle_raster(wiwa_breed, lat = 36.951564, long = -122.065116)
# plot that if you want
if (FALSE) {
plot(gcr)
lines(get_wrld_simpl())
}
Run the code above in your browser using DataLab