powered by
Just simple conversion, but nice to have this in a brief function
isomap2raster(isoscape, column, Proj = raster::projection(get_wrld_simpl()))
the data frame of prediction.txt from ISOMAP. The latitude column must be named "lat" and the longitude column must be named "long".
the name of the column to turn into a raster object. This should be a quoted string, like "predkrig".
the desired projection. By default it is raster::projection(get_wrld_simpl()), i.e. the same projection as the wrld_simpl map.
isorast <- isomap2raster(isomap_job54152_prediction, "predreg") isorast
Run the code above in your browser using DataLab