Learn R Programming

gaiah (version 0.0.5)

isomap_job54152_prediction: Predicted isotope values from ISOMAP

Description

A data frame containing predicted hydrogen isotope values, lat, long, and IDs and some other columns of data prections made by ISOMAP

Usage

isomap_job54152_prediction

Arguments

Format

A tibble with 10,786 rows and 12 variables. The relevant variables for analyses here are:

lat

latitude of the predicted location

long

longitude of the predicted location

predreg

Fill in

stdreg

Fill in

predkrig

Fill in

stdkrig

Fill in