This is a rewrite of the function assignment from the Vander
Zanden appendix code.
vza_assign(rescale_mean, rescale_var, precip_sd, sd_indiv, bird_iso)the tissue specific mean raster, such as the mean.raster
component of the output of vza_mean_and_var_rasters.
tissue specific raster of standard deviations, such as the var.raster
component of the output of vza_mean_and_var_rasters.
SD raster associated with the IsoMAP output. This is the precip component of the variance term.
the individual component of the variance term. This is a value to be determined by the user. The standard approach is to use the mean of the SDs observed among individuals at all of the calibration sites.
a single value giving the isotope ratio found in the individual's feather.
This is a fairly low-level function. It returns a raster of posterior probs (they are scaled to sum to one over all cells).