Learn R Programming

gaiah (version 0.0.5)

vza_rescale: Parametric bootstrap for rescaling a la the vander zanden appendix

Description

This is a vectorized and much more efficient implementation of the original rescale function from the Vander Zanden appendix. It takes the output of group_birds_by_location directly and does the parametric bootstrapping for vza_rescale_reps samples.

Usage

vza_rescale(SBL, vza_rescale_reps = 1000)

Value

Returns a matrix with vza_rescale_reps rows. Column 1 is "intercepts" and column two is "slopes"

Arguments

SBL

the data frame that summarizes the isotope feather data and isoscape predictions at each location. This must have columns of cnt, meanH, sdH, meaniso, sdiso

vza_rescale_reps

Number of simulated regressions to do. Default is 1000.