A data frame containing predicted hydrogen isotope values, lat, long, and IDs and some other columns of data prections made by ISOMAP
isomap_job54152_predictionA tibble with 10,786 rows and 12 variables. The relevant variables for analyses here are:
latitude of the predicted location
longitude of the predicted location
Fill in
Fill in
Fill in
Fill in